JsonFormat

Struct JsonFormat 

pub struct JsonFormat { /* private fields */ }
JSON FileFormat implementation supporting both line-delimited and array formats.

Supported Formats

Line-Delimited JSON (default, newline_delimited = true)

{"key1": 1, "key2": "val"}
{"key1": 2, "key2": "vals"}

JSON Array Format (newline_delimited = false)

[
    {"key1": 1, "key2": "val"},
    {"key1": 2, "key2": "vals"}
]

Note: JSON array format is processed using streaming conversion, which is memory-efficient even for large files.

Implementations

Source

impl JsonFormat

pub fn with_options(self, options: JsonOptions) -> Self

Set JSON options

pub fn options(&self) -> &JsonOptions

Retrieve JSON options

pub fn with_schema_infer_max_rec(self, max_rec: usize) -> Self

Set a limit in terms of records to scan to infer the schema

  • defaults to DEFAULT_SCHEMA_INFER_MAX_RECORD
pub fn with_file_compression_type( self, file_compression_type: FileCompressionType, ) -> Self

Set a FileCompressionType of JSON

  • defaults to FileCompressionType::UNCOMPRESSED
pub fn with_newline_delimited(self, newline_delimited: bool) -> Self

Set whether to read as newline-delimited JSON (NDJSON).

When true (default), expects newline-delimited format:

{"a": 1}
{"a": 2}

When false, expects JSON array format:

[{"a": 1}, {"a": 2}]
pub fn is_newline_delimited(&self) -> bool

Returns whether this format expects newline-delimited JSON.